"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const aws_sdk_1 = require("aws-sdk");
const lib_1 = require("../lib");
function checkForAliasConfig(pkgJson, handler) {
    return __awaiter(this, void 0, void 0, function* () {
        const domains = pkgJson.seagull && pkgJson.seagull.domains;
        const needAliases = domains && domains.length > 0;
        return needAliases ? yield getAliasConfig(domains, handler) : undefined;
    });
}
exports.checkForAliasConfig = checkForAliasConfig;
function getAliasConfig(domains, handler) {
    return __awaiter(this, void 0, void 0, function* () {
        const arns = yield handler.listCertificates();
        const getArnDomains = (arn) => __awaiter(this, void 0, void 0, function* () { return getCertDomains(arn, handler); });
        const arnsWithSchemata = yield Promise.all(arns.map(getArnDomains));
        return lib_1.findAliasConfig(arnsWithSchemata, domains);
    });
}
function getCertDomains(acmCertRef, handler) {
    return __awaiter(this, void 0, void 0, function* () {
        return { acmCertRef, names: yield handler.describeCertificate(acmCertRef) };
    });
}
class ACMHandler {
    constructor() {
        const credentials = aws_sdk_1.config.credentials;
        this.acm = new aws_sdk_1.ACM({ credentials, region: 'us-east-1' });
    }
    listCertificates() {
        return __awaiter(this, void 0, void 0, function* () {
            const params = { CertificateStatuses: ['ISSUED'] };
            const response = yield this.acm.listCertificates(params).promise();
            const certSumList = (response && response.CertificateSummaryList) || [];
            const arns = certSumList.map(certSum => certSum && certSum.CertificateArn);
            return arns.filter(arn => arn !== undefined);
        });
    }
    describeCertificate(acmCertRef) {
        return __awaiter(this, void 0, void 0, function* () {
            const params = { CertificateArn: acmCertRef };
            const description = yield this.acm.describeCertificate(params).promise();
            const cert = description.Certificate;
            return (cert && cert.SubjectAlternativeNames) || [];
        });
    }
}
exports.ACMHandler = ACMHandler;
//# sourceMappingURL=handle_acm.js.map