"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const aws_sdk_1 = require("aws-sdk");
function emptyBucket(s3Handler, bucketName) {
    return __awaiter(this, void 0, void 0, function* () {
        s3Handler.deleteObjects(bucketName, yield s3Handler.listObjects(bucketName));
    });
}
exports.emptyBucket = emptyBucket;
class S3Handler {
    constructor() {
        const { credentials, region } = aws_sdk_1.config;
        this.s3 = new aws_sdk_1.S3({ credentials, region });
    }
    listObjects(bucketName) {
        return __awaiter(this, void 0, void 0, function* () {
            const list = [];
            const params = { Bucket: bucketName };
            let truncated = true;
            while (truncated) {
                const response = yield this.s3.listObjectsV2(params).promise();
                params.ContinuationToken = response.NextContinuationToken;
                truncated = !!response.IsTruncated;
                const contents = response && response.Contents || [];
                contents.forEach(item => item && item.Key && list.push(item.Key));
            }
            return list;
        });
    }
    deleteObject(bucketName, key) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.s3.deleteObject({ Bucket: bucketName, Key: key }).promise();
        });
    }
    deleteObjects(bucketName, keys) {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.all(keys.map(key => this.deleteObject(bucketName, key)));
        });
    }
}
exports.S3Handler = S3Handler;
//# sourceMappingURL=handle_s3.js.map