"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get_stage_configs_1 = require("./get_stage_configs");
const buildActionOutputArtifacts = (workers) => {
    const artifacts = {};
    [...Array(workers).keys()].forEach(i => {
        const build = `build${i}`;
        const dist = `dist${i}`;
        artifacts[build] = { files: ['dist/**/*'], name: build };
        artifacts[dist] = { files: ['dist/**/*'], name: dist };
    });
    return {
        'primary-artifacts': {},
        'secondary-artifacts': artifacts,
    };
};
const deployActionOutputArtifacts = {
    'secondary-artifacts': {
        cfurl: {
            files: ['/tmp/cfurl.txt'],
            name: 'cfurl',
        },
        deploy: {
            files: '**/*',
            name: 'deploy',
        },
    },
};
function addPipelineStages(stack, params) {
    const sourceAction = stack.addSourceStage('source', get_stage_configs_1.getSourceConfig(params, 0));
    const buildActions = stack.addBuildActionStage('build', Object.assign({}, get_stage_configs_1.getBuildConfig(params, 1, sourceAction.outputArtifact), { outputArtifacts: buildActionOutputArtifacts(params.buildWorkers) }), get_stage_configs_1.getTestConfig(params, 1, sourceAction.outputArtifact), params.buildWorkers);
    const deployInput = buildActions.map((a, i) => a.additionalOutputArtifact(`dist${i}`));
    const deployAction = stack.addDeployActionStage('deploy', Object.assign({}, get_stage_configs_1.getDeployConfig(params, 2, sourceAction.outputArtifact), { additionalInputArtifacts: deployInput, outputArtifacts: deployActionOutputArtifacts }));
    stack.addGenericBuildActionStage('end2end-test', Object.assign({}, get_stage_configs_1.getTestEnd2EndConfig(params, 3, sourceAction.outputArtifact), { additionalInputArtifacts: [deployAction.additionalOutputArtifact('cfurl')] }));
}
exports.addPipelineStages = addPipelineStages;
//# sourceMappingURL=build_pipeline.js.map