"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const cdk_1 = require("@aws-cdk/cdk");
const cfnDiff = require("@aws-cdk/cloudformation-diff");
const cdk = require("aws-cdk");
const yaml = require("yaml");
const lib = require("./lib");
const seagull_stack_1 = require("./seagull_stack");
class SeagullApp extends cdk_1.App {
    constructor(props) {
        super();
        const { projectName, stackProps } = props;
        this.projectName = projectName;
        this.stack = new seagull_stack_1.SeagullStack(this, projectName, stackProps);
    }
    deployStack() {
        return __awaiter(this, void 0, void 0, function* () {
            const sdk = new cdk.SDK({});
            const synthStack = this.synthesizeStack(this.projectName);
            const env = synthStack.environment;
            yield cdk.bootstrapEnvironment(env, sdk, 'CDKToolkit', undefined);
            const toolkitInfo = yield cdk.loadToolkitInfo(env, sdk, 'CDKToolkit');
            yield cdk.deployStack({ sdk, stack: synthStack, toolkitInfo });
        });
    }
    destroyStack() {
        return __awaiter(this, void 0, void 0, function* () {
            const sdk = new cdk.SDK({});
            const synthStack = this.synthesizeStack(this.projectName);
            const env = synthStack.environment;
            yield cdk.bootstrapEnvironment(env, sdk, 'CDKToolkit', undefined);
            yield cdk.destroyStack({ sdk, stack: synthStack });
        });
    }
    diffStack() {
        return __awaiter(this, void 0, void 0, function* () {
            const sdk = new cdk.SDK({});
            const synthStack = this.synthesizeStack(this.projectName);
            const cfn = yield sdk.cloudFormation(synthStack.environment, 0);
            const templateData = { StackName: synthStack.name };
            const template = yield cfn.getTemplate(templateData).promise();
            const body = template.TemplateBody;
            const curTemplate = (body && yaml.parse(body, { schema: 'yaml-1.1' })) || {};
            const logicalToPathMap = lib.createLogicalToPathMap(synthStack);
            const diff = cfnDiff.diffTemplate(curTemplate, synthStack.template);
            diff.isEmpty && lib.noChangesInDiff();
            cfnDiff.formatDifferences(process.stdout, diff, logicalToPathMap);
        });
    }
}
exports.SeagullApp = SeagullApp;
//# sourceMappingURL=seagull_app.js.map